@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
 use Carp;
 use Furl;
@@ -306,7 +306,7 @@ sub batch_get_item {
     my $decoded = $self->json->decode($res->content);
     if ($res->is_success) {
         my $res;
-        for my $k (keys $decoded->{Responses}) {
+        for my $k (keys %{$decoded->{Responses}}) {
             push @{$res}, {$k => _except_type($decoded->{Responses}->{$k})};
         }
         return $res;
@@ -356,9 +356,10 @@ sub _except_type {
 sub _error_content {
     my ($self, $res, $decoded) = @_;
 
+    my $message = $decoded->{Message} ? $decoded->{Message} : $decoded->{message};
     return  "status_code : " . $res->status_line
       . " __type : " . $decoded->{__type}
-      . " message : " . $decoded->{Message};
+      . " message : " . $message;
 }
 
 
@@ -1339,7 +1340,7 @@ Puts or Deletes multiple items in one or more tables.
                                 "BS" => [
                                     "blob"
                                 ],
-                                "L" =< [
+                                "L" => [
                                     AttributeValue
                                 ],
                                 "M" => {
